@@ -1,3 +1,6 @@
+from annolab.project_import import ProjectImport
+import os
+
 from annolab import endpoints
 from annolab.project import Project
 from annolab.api_helper import ApiHelper
@@ -39,7 +42,7 @@ class AnnoLab:
     return Project.create_from_response_json(res.json(), self.__api)
 
 
-  def create_project(self, name: str, owner_name: str = None):
+  def create_project(self, name: str, owner_name: str = None, is_public = False):
     """
       Create a project.
       If group name is not passed, the user's default group is used.
@@ -50,8 +53,24 @@ class AnnoLab:
       endpoints.Project.post_create(),
       {
         'name': name,
-        'groupName': owner_name
+        'groupName': owner_name,
+        'isPublic': is_public
       }
     )
 
     return Project.create_from_response_json(res.json(), self.__api)
+
+
+  def create_project_from_export(self, filepath: str, name: str = None, owner_name: str = None, is_public=False):
+    if (name is None):
+      name = os.path.basename(filepath).split('.')[0]
+
+    project = self.create_project(name, owner_name, is_public=is_public)
+    project_import = ProjectImport(filepath, project, owner_name)
+
+    project_import.unzip_export()
+    project_import.import_all()
+    project_import.cleanup()
+
+    return project
+
