@@ -9,20 +9,22 @@ class AnnotationRelation:
     Maps an sdk relation dict to an api annotation relation dict, for use in calls to the api.
 
     AnnotationRelation parameters:
-      annotations: [Union[str, int], Union[str, int]]
-      type:        str
-      schema:      str
-      value:       str
-      reviewed     bool (Optional)
+      annotations:      [Union[str, int], Union[str, int]]
+      type:             str
+      schema:           str
+      value:            str
+      reviewed          bool (Optional)
+      project           Union[str, int]
     """
     relation = {
       'predecessorId': str(dict['annotations'][0]),
       'successorId': str(dict['annotations'][1])
     }
 
-    if ('type' in dict): relation['typeIdentifier'] = dict['client_id']
+    if ('type' in dict): relation['annoTypeIdentifier'] = dict['type']
     if ('schema' in dict): relation['schemaIdentifier'] = dict['schema']
     if ('value' in dict): relation['value'] = dict['value']
     if ('reviewed' in dict): relation['isReviewed'] = dict['reviewed']
+    if ('project' in dict): relation['projectIdentifier'] = dict['project']
 
     return relation
\ No newline at end of file
